@@ -6,7 +6,6 @@ use std::path::{Path, PathBuf};
 use std::time::Duration;
 
 use once_cell::unsync::OnceCell;
-use yansi::Color::{Green, Red};
 use yansi::Paint;
 use zip::ZipArchive;
 
@@ -47,7 +46,14 @@ impl<'a> Cache<'a> {
     /// Send a GET request with the provided agent and return the response body.
     fn get_asset(agent: &ureq::Agent, url: &str) -> Result<Vec<u8>> {
         info_start!("downloading '{}'... ", url.split('/').last().unwrap());
-        let resp = agent.get(url).call()?;
+
+        let resp = match agent.get(url).call() {
+            Ok(r) => r,
+            Err(e) => {
+                info_end!("{}", "FAILED".red().bold());
+                return Err(e.into());
+            }
+        };
 
         let content_length = resp
             .header("Content-Length")
@@ -55,14 +61,17 @@ impl<'a> Cache<'a> {
             .parse()
             .unwrap_or_default();
         let mut buf = Vec::with_capacity(content_length);
-        resp.into_reader().read_to_end(&mut buf)?;
+        if let Err(e) = resp.into_reader().read_to_end(&mut buf) {
+            info_end!("{}", "FAILED".red().bold());
+            return Err(e.into());
+        }
 
         #[allow(clippy::cast_precision_loss)]
         let dl_kib = buf.len() as f64 / 1024.0;
         if dl_kib < 1024.0 {
-            info_end!("{:.02} KiB", Paint::new(dl_kib).fg(Green).bold());
+            info_end!("{:.02} KiB", dl_kib.green().bold());
         } else {
-            info_end!("{:.02} MiB", Paint::new(dl_kib / 1024.0).fg(Green).bold());
+            info_end!("{:.02} MiB", (dl_kib / 1024.0).green().bold());
         }
 
         Ok(buf)
@@ -103,11 +112,11 @@ impl<'a> Cache<'a> {
             }
 
             let archive = Self::get_asset(&agent, &format!("{mirror}/tldr-pages.{lang}.zip"))?;
-            info_start!("validating sha256sums...");
+            info_start!("validating sha256sums... ");
             let actual_sum = util::sha256_hexdigest(&archive);
 
             if sum != &actual_sum {
-                info_end!(" {}", Paint::new("FAILED").fg(Red).bold());
+                info_end!("{}", "FAILED".red().bold());
                 return Err(Error::new(format!(
                     "SHA256 sum mismatch!\n\
                     expected : {sum}\n\
@@ -115,7 +124,7 @@ impl<'a> Cache<'a> {
                 )));
             }
 
-            info_end!(" {}", Paint::new("OK").fg(Green).bold());
+            info_end!(" {}", "OK".green().bold());
 
             langdir_archive_map.insert(lang_dir, ZipArchive::new(Cursor::new(archive))?);
         }
@@ -167,7 +176,7 @@ impl<'a> Cache<'a> {
         all_downloaded: &mut i32,
         all_new: &mut i32,
     ) -> Result<()> {
-        info_start!("extracting '{lang_dir}'...");
+        info_start!("extracting '{lang_dir}'... ");
 
         let mut n_downloaded = 0;
 
@@ -198,9 +207,9 @@ impl<'a> Cache<'a> {
         *all_new += n_new;
 
         info_end!(
-            " {} pages, {} new",
-            Paint::new(n_downloaded).fg(Green).bold(),
-            Paint::new(n_new).fg(Green).bold()
+            "{} pages, {} new",
+            n_downloaded.green().bold(),
+            n_new.green().bold()
         );
 
         Ok(())
@@ -235,19 +244,22 @@ impl<'a> Cache<'a> {
                 fs::remove_dir_all(&lang_dir_full)?;
             }
 
-            self.extract_lang_archive(
+            if let Err(e) = self.extract_lang_archive(
                 &lang_dir,
                 &mut archive,
                 n_existing,
                 &mut all_downloaded,
                 &mut all_new,
-            )?;
+            ) {
+                info_end!("{}", "FAILED".red().bold());
+                return Err(e);
+            }
         }
 
         infoln!(
             "cache update successful (total: {} pages, {} new).",
-            Paint::new(all_downloaded).fg(Green).bold(),
-            Paint::new(all_new).fg(Green).bold(),
+            all_downloaded.green().bold(),
+            all_new.green().bold(),
         );
 
         Ok(())
@@ -303,7 +315,7 @@ impl<'a> Cache<'a> {
         if platforms.iter().all(|x| x != platform) {
             Err(Error::new(format!(
                 "platform '{platform}' does not exist.\n{} {}.",
-                Paint::new("Possible values:").bold(),
+                "Possible values:".bold(),
                 platforms.join(", ".as_ref()).to_string_lossy()
             )))
         } else {
@@ -506,8 +518,8 @@ impl<'a> Cache<'a> {
         writeln!(
             stdout,
             "Cache: {} (last update: {} ago)",
-            Paint::new(self.dir.display()).fg(Red),
-            Paint::new(util::duration_fmt(age)).fg(Green).bold()
+            self.dir.display().red(),
+            util::duration_fmt(age).green().bold()
         )?;
 
         if cfg.cache.auto_update {
@@ -516,7 +528,7 @@ impl<'a> Cache<'a> {
             writeln!(
                 stdout,
                 "Automatic update in {}",
-                Paint::new(util::duration_fmt(age_diff)).fg(Green).bold()
+                util::duration_fmt(age_diff).green().bold()
             )?;
         } else {
             writeln!(stdout, "Automatic updates are disabled")?;
@@ -529,15 +541,11 @@ impl<'a> Cache<'a> {
                 stdout,
                 // Language codes are at most 5 characters (ll_CC).
                 "{lang:5} : {}",
-                Paint::new(n).fg(Green).bold(),
+                n.green().bold(),
             )?;
         }
 
-        writeln!(
-            stdout,
-            "total : {} pages",
-            Paint::new(n_total).fg(Green).bold(),
-        )?;
+        writeln!(stdout, "total : {} pages", n_total.green().bold())?;
 
         Ok(())
     }
