@@ -4,7 +4,6 @@ use std::io::{self, BufRead, BufReader, BufWriter, Write};
 use std::path::{Path, PathBuf};
 use std::sync::atomic::Ordering::Relaxed;
 
-use yansi::Color::Green;
 use yansi::{Paint, Style};
 
 use crate::config::Config;
@@ -48,7 +47,7 @@ impl<'a> PageRenderer<'a> {
         let split: Vec<&str> = s.split('`').collect();
         // Highlight beginning not found.
         if split.len() == 1 {
-            return style_normal.paint(s).to_string();
+            return s.paint(style_normal).to_string();
         }
 
         let mut buf = String::new();
@@ -62,9 +61,9 @@ impl<'a> PageRenderer<'a> {
             // 3: "dd"      (highlighted)
             // 4: " ee"
             if i % 2 == 0 {
-                buf += &style_normal.paint(part).to_string();
+                buf += &part.paint(style_normal).to_string();
             } else {
-                buf += &self.style.inline_code.paint(part).to_string();
+                buf += &part.paint(self.style.inline_code).to_string();
             }
         }
 
@@ -75,7 +74,7 @@ impl<'a> PageRenderer<'a> {
         let split: Vec<&str> = s.split("<http").collect();
         // Highlight beginning not found.
         if split.len() == 1 {
-            return style_normal.paint(s).to_string();
+            return s.paint(style_normal).to_string();
         }
 
         let mut buf = String::new();
@@ -92,11 +91,11 @@ impl<'a> PageRenderer<'a> {
 
                 // "<http" is used to detect URLs. It must be added back.
                 let hl = format!("http{}", part_split.0);
-                buf += &self.style.url.paint(hl).to_string();
-                buf += &style_normal.paint(part_split.1).to_string();
+                buf += &hl.paint(self.style.url).to_string();
+                buf += &part_split.1.paint(style_normal).to_string();
             } else {
                 // Highlight ending not found.
-                buf += &style_normal.paint(part).to_string();
+                buf += &part.paint(style_normal).to_string();
             }
         }
 
@@ -107,7 +106,7 @@ impl<'a> PageRenderer<'a> {
         let split: Vec<&str> = s.split("{{").collect();
         // Highlight beginning not found.
         if split.len() == 1 {
-            return style_normal.paint(s).to_string();
+            return s.paint(style_normal).to_string();
         }
 
         let mut buf = String::new();
@@ -128,11 +127,11 @@ impl<'a> PageRenderer<'a> {
                 let idx = part.rmatch_indices("}}").last().unwrap().0;
                 let part_split = part.split_at(idx);
 
-                buf += &self.style.placeholder.paint(part_split.0).to_string();
-                buf += &style_normal.paint(&part_split.1[2..]).to_string();
+                buf += &part_split.0.paint(self.style.placeholder).to_string();
+                buf += &part_split.1[2..].paint(style_normal).to_string();
             } else {
                 // Highlight ending not found.
-                buf += &style_normal.paint(part).to_string();
+                buf += &part.paint(style_normal).to_string();
             }
         }
 
@@ -193,7 +192,7 @@ impl<'a> PageRenderer<'a> {
                 writeln!(
                     stderr,
                     "{} {platform:<width$} (tldr --platform {platform} {name})",
-                    Paint::new(format!("{}.", i + 1)).fg(Green).bold(),
+                    format!("{}.", i + 1).green().bold(),
                 )?;
             }
         }
@@ -205,11 +204,18 @@ impl<'a> PageRenderer<'a> {
 
     /// Load the next line into the line buffer.
     fn next_line(&mut self) -> Result<usize> {
-        self.current_line.clear();
+        // The `Paint` trait from yansi also has a method named `clear`.
+        // This will be resolved in a future release: https://github.com/SergioBenitez/yansi/issues/42
+        //self.current_line.clear();
+        String::clear(&mut self.current_line);
         self.lnum += 1;
-        self.reader
+        let n = self
+            .reader
             .read_line(&mut self.current_line)
-            .map_err(|e| Error::new(format!("'{}': {e}", self.path.display())))
+            .map_err(|e| Error::new(format!("'{}': {e}", self.path.display())))?;
+        self.current_line
+            .truncate(self.current_line.trim_end().len());
+        Ok(n)
     }
 
     /// Write the current line to the page buffer as a title.
@@ -230,9 +236,9 @@ impl<'a> PageRenderer<'a> {
             Cow::Borrowed(line)
         };
 
-        let title = self.style.title.paint(title);
+        let title = title.paint(self.style.title);
         let indent = " ".repeat(self.cfg.indent.title);
-        write!(self.stdout, "{indent}{title}")?;
+        writeln!(self.stdout, "{indent}{title}")?;
 
         Ok(())
     }
@@ -247,7 +253,7 @@ impl<'a> PageRenderer<'a> {
             self.style.desc,
         );
         let indent = " ".repeat(self.cfg.indent.description);
-        write!(self.stdout, "{indent}{desc}")?;
+        writeln!(self.stdout, "{indent}{desc}")?;
 
         Ok(())
     }
@@ -264,7 +270,7 @@ impl<'a> PageRenderer<'a> {
 
         let bullet = self.hl_code(&self.hl_url(line, self.style.bullet), self.style.bullet);
         let indent = " ".repeat(self.cfg.indent.bullet);
-        write!(self.stdout, "{indent}{bullet}")?;
+        writeln!(self.stdout, "{indent}{bullet}")?;
 
         Ok(())
     }
@@ -282,7 +288,6 @@ impl<'a> PageRenderer<'a> {
             .current_line
             .strip_prefix(EXAMPLE)
             .unwrap()
-            .trim_end()
             .strip_suffix('`')
             .ok_or_else(|| {
                 Error::parse_page(self.path, self.lnum, &self.current_line)
